@ECHO OFF

SETLOCAL

REM Determine whether the machine is running a 32-bit or 64-bit operation system.
REG Query "HKLM\Hardware\Description\System\CentralProcessor\0" | FIND /i "x86" > NUL && (SET BITS=32) || (SET BITS=64)

IF %BITS%==32 ECHO [ERROR] This SDK does not support 32-bit installations, please contact Red Rapids.
IF %BITS%==32 ECHO Exiting batch file...

REM Set the architecture and libraries depending on the machine type (32-bit vs 64-bit).
IF %BITS%==64 (SET MACHINE=/MACHINE:X64)

REM Set additional paths if the 64-bit Windows 10 SDK is loaded.
IF EXIST "C:\Program Files (x86)\Windows Kits\10\Include\10.0.10240.0\ucrt" (SET SDK_INCLUDE=/I "C:\Program Files (x86)\Windows Kits\10\Include\10.0.10240.0\ucrt")
IF EXIST "C:\Program Files (x86)\Windows Kits\10\Lib\10.0.10240.0\ucrt\x64" (SET SDK_LIBPATH=/LIBPATH:"C:\Program Files (x86)\Windows Kits\10\Lib\10.0.10240.0\ucrt\x64")

REM Delete existing object, executable, and library files, but not the RRadapter.dll or wdapixxxx.dll files for the RRadapter driver.
REM Note: The RRadapter.dll and wdapixxxx.dll files are provided in the RRadapter subdirectory.
DEL obj\*.* exe\*.exe exe\RRadapter_ISR.dll exe\*.exp exe\*.lib /Q

REM Compile all of the source code.
CL /c /MT /W3 /I include %SDK_INCLUDE% /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_DEPRECATE /D _UNICODE /D UNICODE /Foobj\\ flash*.c src\*.c

REM If there have been no prior errors, link the interrupt service routine (ISR) DLL that is required by the RRadapter driver.
IF %ERRORLEVEL% EQU 0 (LINK /DLL /INCREMENTAL:NO /SUBSYSTEM:WINDOWS /OPT:REF %SDK_LIBPATH% /LIBPATH:..\drivers\win_x86-%BITS%\lib /OUT:exe\RRadapter_ISR.dll obj\RRadapter_ISR*.obj obj\global_functions*.obj obj\dma_functions*.obj obj\channel_functions*.obj obj\chip_functions*.obj obj\utility_functions*.obj RRadapter.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib)

REM If there have been no prior errors, link the application.
IF %ERRORLEVEL% EQU 0 (LINK /INCREMENTAL:NO /SUBSYSTEM:CONSOLE /OPT:REF %MACHINE% %SDK_LIBPATH%  /LIBPATH:..\drivers\win_x86-%BITS%\lib /OUT:exe\flash.exe obj\*.obj RRadapter.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib)

ENDLOCAL